/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef, OnDestroy, ElementRef, NgZone, OnChanges, Renderer2, AfterViewChecked } from '@angular/core';
import { PopupService, PopupRef, Collision } from '@progress/kendo-angular-popup';
import { TooltipSettings } from './tooltip.settings';
import { Position } from '../models/position.type';
import { ShowOption } from '../models/show.option.type';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Tooltip directive for Angular]({% slug overview_tooltip %}).
 * Displays additional information related to an element.
 *
 * @example
 * ```html
 * <div kendoTooltip>
 *   <button kendoButton title="Save">Save</button>
 * </div>
 * ```
 */
export declare class TooltipDirective implements OnDestroy, OnChanges, AfterViewChecked {
    tooltipWrapper: ElementRef;
    ngZone: NgZone;
    private renderer;
    private popupService;
    /**
     * Specifies a selector for elements within a container that display a tooltip
     * ([see example]({% slug anchorelements_tooltip %})). The possible values include any
     * DOM `selector`.
     * @default '[title]'
     */
    filter: string;
    /**
     * Specifies the position of the Tooltip relative to the
     * anchor element ([see example]({% slug positioning_tooltip %})).
     *
     * @default 'top'
     */
    position: Position;
    /**
     * Sets the template for the tooltip header title. [See example]({% slug anchorelements_tooltip %}).
     */
    titleTemplate?: TemplateRef<any>;
    /**
     * Specifies the mouse action that triggers the Tooltip to show. [See example]({% slug programmaticopening_tooltip %}).
     */
    showOn: ShowOption;
    /**
     * Specifies the delay in milliseconds before the Tooltip is shown.
     *
     * @default 100
     */
    showAfter: number;
    /**
     * Determines if the Tooltip displays a callout arrow.
     *
     * @default true
     */
    callout: boolean;
    /**
     * Determines if the Tooltip displays a **Close** button. [See example]({% slug closable_tooltip %}).
     *
     * @default false
     */
    closable: boolean;
    /**
     * Specifies the offset in pixels between the Tooltip and the anchor.
     * If the `callout` property is set to `true`, the offset is rendered from the callout arrow.
     * If the `callout` property is set to `false`, the offset is rendered from the content of the Tooltip.
     *
     * @default 6
     */
    offset: number;
    /**
     * Sets the width of the Tooltip. [See example]({% slug anchorelements_tooltip %}).
     */
    tooltipWidth: number;
    /**
     * Sets the height of the Tooltip.
     */
    tooltipHeight: number;
    /**
     * Sets a CSS class for the Tooltip.
     */
    tooltipClass: string;
    /**
     * @hidden
     * Specifies a CSS class that will be added to the kendo-tooltip element.
     */
    tooltipContentClass: string;
    /**
     * Provides screen boundary detection when the Тooltip is shown.
     */
    collision: Collision;
    /**
     * Sets the title of the **Close** button.
     */
    closeTitle: string;
    /**
     * Sets a custom content template for the Tooltip.
     * The template is rendered inside the Tooltip content area. [See example]({% slug templates_tooltip %}).
     */
    set tooltipTemplate(value: TemplateRef<any>);
    get tooltipTemplate(): TemplateRef<any>;
    popupRef: PopupRef;
    template: TemplateRef<any>;
    private showTimeout;
    private anchor;
    private mouseOverSubscription;
    private mouseOutSubscription;
    private mouseClickSubscription;
    private anchorTitleSubscription;
    private popupPositionChangeSubscription;
    private popupMouseOutSubscription;
    private keyboardNavigationSubscription;
    private closeClickSubscription;
    private validPositions;
    private validShowOptions;
    constructor(tooltipWrapper: ElementRef, ngZone: NgZone, renderer: Renderer2, popupService: PopupService, settings: TooltipSettings, legacySettings: TooltipSettings);
    /**
     * Shows the Tooltip.
     * @param anchor - The element used as an anchor. The Tooltip opens relative to this element.
     */
    show(anchor: ElementRef | Element): void;
    /**
     * Hides the Tooltip.
     */
    hide(): void;
    /**
     * Toggles the visibility of the Tooltip.
     * @param anchor - The element used as an anchor.
     * @param show - Optional. Boolean. Specifies if the Tooltip is rendered.
     */
    toggle(anchor: ElementRef | Element, show?: boolean): void;
    ngOnInit(): void;
    ngOnChanges(changes: any): void;
    ngAfterViewChecked(): void;
    ngOnDestroy(): void;
    private showContent;
    private bindContent;
    private hideElementTitle;
    private openPopup;
    private closePopup;
    private subscribeClick;
    private onMouseClick;
    private onKeyDown;
    private canCloseTooltip;
    private onMouseOver;
    private onMouseOut;
    private verifyProperties;
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipDirective, [null, null, null, null, { optional: true; }, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TooltipDirective, "[kendoTooltip]", ["kendoTooltip"], { "filter": { "alias": "filter"; "required": false; }; "position": { "alias": "position"; "required": false; }; "titleTemplate": { "alias": "titleTemplate"; "required": false; }; "showOn": { "alias": "showOn"; "required": false; }; "showAfter": { "alias": "showAfter"; "required": false; }; "callout": { "alias": "callout"; "required": false; }; "closable": { "alias": "closable"; "required": false; }; "offset": { "alias": "offset"; "required": false; }; "tooltipWidth": { "alias": "tooltipWidth"; "required": false; }; "tooltipHeight": { "alias": "tooltipHeight"; "required": false; }; "tooltipClass": { "alias": "tooltipClass"; "required": false; }; "tooltipContentClass": { "alias": "tooltipContentClass"; "required": false; }; "collision": { "alias": "collision"; "required": false; }; "closeTitle": { "alias": "closeTitle"; "required": false; }; "tooltipTemplate": { "alias": "tooltipTemplate"; "required": false; }; }, {}, never, never, true, never>;
}
